# susan_collins
Use `Concern` everywhere

Sets the global `Concern` to [`ActiveSupport::Concern`][ASC] so you don't have to type those pesky extra characters.

[ASC]: https://api.rubyonrails.org/classes/ActiveSupport/Concern.html

## Usage
In either your Gemfile or code, require the main module:

```ruby
# Gemfile
gem "susan_collins"

# or
require "susan_collins"
```

You can now:

```ruby
module DeepConcern
  extend Concern

  class_methods do
    # ...
  end

  included do
    # ...
  end

  # ...
end
```

With the regular require, you get [`concerning`][MC] too:

```ruby
class TremendouslyLargeClass
  # ...
  include DeepConcern

  concerning :SeriousConcerns do
    # ...
  end
end
```

[MC]: https://api.rubyonrails.org/classes/Module/Concerning.html

### Just Concern
If you don't want `Module#concerning`:

```ruby
# Gemfile
gem "susan_collins", require: "susan_collins/deep_concern"

# or
require "susan_collins/deep_concern"
```

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'susan_collins'
```

And then execute:

    $ bundle install

Or install it yourself as:

    $ gem install susan_collins

## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run `rake spec` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/joallard/susan_collins. This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [code of conduct](https://github.com/joallard/susan_collins/blob/master/CODE_OF_CONDUCT.md).


## Code of Conduct

Everyone interacting in the SusanCollins project's codebases, issue trackers, chat rooms and mailing lists is expected to follow the [code of conduct](https://github.com/joallard/susan_collins/blob/master/CODE_OF_CONDUCT.md).
